@@ -24,12 +24,15 @@ use serde_json::Value;
 pub use callback_executors::NullRequestFilterExecutor;
 use callback_executors::RequestFilterExecutor;
 use pact_matching::*;
-use pact_matching::models::*;
-use pact_matching::models::generators::GeneratorTestMode;
-use pact_matching::models::http_utils::HttpAuth;
-use pact_matching::models::v4::V4Interaction;
+use pact_matching::logging::LOG_ID;
+use pact_models::generators::GeneratorTestMode;
+use pact_models::http_utils::HttpAuth;
+use pact_models::interaction::Interaction;
 use pact_models::json_utils::json_to_string;
+use pact_models::pact::{load_pact_from_url, Pact, read_pact};
 use pact_models::provider_states::*;
+use pact_models::sync_interaction::RequestResponseInteraction;
+use pact_models::v4::interaction::V4Interaction;
 
 use crate::callback_executors::{ProviderStateError, ProviderStateExecutor};
 use crate::messages::{display_message_result, verify_message_from_provider};
@@ -559,6 +562,7 @@ pub async fn verify_provider_async<F: RequestFilterExecutor, S: ProviderStateExe
     options: VerificationOptions<F>,
     provider_state_executor: &Arc<S>
 ) -> bool {
+  LOG_ID.scope(format!("verify:{}", provider_info.name), async {
     let pact_results = fetch_pacts(source, consumers).await;
 
     let mut results: Vec<(Option<String>, Result<(), MismatchResult>)> = vec![];
@@ -630,6 +634,7 @@ pub async fn verify_provider_async<F: RequestFilterExecutor, S: ProviderStateExe
       println!();
       true
     }
+  }).await
 }
 
 fn print_errors(errors: &Vec<(String, MismatchResult)>) {
@@ -660,6 +665,8 @@ fn print_errors(errors: &Vec<(String, MismatchResult)>) {
 }
 
 async fn fetch_pact(source: PactSource) -> Vec<Result<(Box<dyn Pact>, Option<PactVerificationContext>, PactSource), String>> {
+  trace!("fetch_pact(source={})", source);
+
   match source {
     PactSource::File(ref file) => vec![read_pact(Path::new(&file))
       .map_err(|err| format!("Failed to load pact '{}' - {}", file, err))
@@ -745,6 +752,8 @@ async fn fetch_pact(source: PactSource) -> Vec<Result<(Box<dyn Pact>, Option<Pac
 
 async fn fetch_pacts(source: Vec<PactSource>, consumers: Vec<String>)
   -> Vec<Result<(Box<dyn Pact>, Option<PactVerificationContext>, PactSource), String>> {
+  trace!("fetch_pacts(source={:?}, consumers={:?})", source, consumers);
+
   futures::stream::iter(source)
     .then(|pact_source| async {
       futures::stream::iter(fetch_pact(pact_source).await)
