@@ -15,10 +15,11 @@ use serde_with::skip_serializing_none;
 use tokio::time::{Duration, sleep};
 
 use pact_matching::Mismatch;
-use pact_matching::models::{Pact, PACT_RUST_VERSION, RequestResponsePact};
-use pact_matching::models::http_utils::HttpAuth;
-use pact_matching::models::message_pact::MessagePact;
-use pact_matching::s;
+use pact_models::http_utils::HttpAuth;
+use pact_models::message_pact::MessagePact;
+use pact_models::pact::Pact;
+use pact_models::PACT_RUST_VERSION;
+use pact_models::sync_pact::RequestResponsePact;
 
 use crate::MismatchResult;
 
@@ -44,7 +45,7 @@ fn as_string(json: &serde_json::Value) -> String {
 fn content_type(response: &reqwest::Response) -> String {
     match response.headers().get("content-type") {
         Some(value) => value.to_str().unwrap_or("text/plain").into(),
-        None => s!("text/plain")
+        None => "text/plain".to_string()
     }
 }
 
@@ -207,6 +208,8 @@ impl HALClient {
     link: &'static str,
     template_values: &HashMap<String, String>
   ) -> Result<HALClient, PactBrokerError> {
+    trace!("navigate(link='{}', template_values={:?})", link, template_values);
+
     let client = if self.path_info.is_none() {
       let path_info = self.clone().fetch("/".into()).await?;
       self.update_path_info(path_info)
@@ -244,6 +247,8 @@ impl HALClient {
         link: &'static str,
         template_values: &HashMap<String, String>
     ) -> Result<serde_json::Value, PactBrokerError> {
+      trace!("fetch_link(link='{}', template_values={:?})", link, template_values);
+
         let link_data = self.find_link(link)?;
 
         self.fetch_url(&link_data, template_values).await
@@ -255,6 +260,8 @@ impl HALClient {
     link: &Link,
     template_values: &HashMap<String, String>
   ) -> Result<serde_json::Value, PactBrokerError> {
+    trace!("fetch_url(link={:?}, template_values={:?})", link, template_values);
+
       let link_url = if link.templated {
           log::debug!("Link URL is templated");
           self.clone().parse_link_url(&link, &template_values)
@@ -285,7 +292,8 @@ impl HALClient {
     let request_builder = match self.auth {
         Some(ref auth) => match auth {
             HttpAuth::User(username, password) => self.client.get(url).basic_auth(username, password.clone()),
-            HttpAuth::Token(token) => self.client.get(url).bearer_auth(token)
+            HttpAuth::Token(token) => self.client.get(url).bearer_auth(token),
+            _ => self.client.get(url)
         },
         None => self.client.get(url)
     }.header("accept", "application/hal+json, application/json");
@@ -396,15 +404,19 @@ impl HALClient {
   }
 
   async fn post_json(&self, url: &str, body: &str) -> Result<serde_json::Value, PactBrokerError> {
+    trace!("post_json(url='{}', body='{}')", url, body);
+
     self.send_document(url, body, Method::POST).await
   }
 
   async fn put_json(&self, url: &str, body: &str) -> Result<serde_json::Value, PactBrokerError> {
+    trace!("put_json(url='{}', body='{}')", url, body);
+
     self.send_document(url, body, Method::PUT).await
   }
 
   async fn send_document(&self, url: &str, body: &str, method: Method) -> Result<serde_json::Value, PactBrokerError> {
-    log::debug!("Sending JSON to {} using {}: {}", url, method, body);
+    debug!("Sending JSON to {} using {}: {}", url, method, body);
 
     let url = url.parse::<reqwest::Url>()
       .map_err(|err| PactBrokerError::UrlError(format!("{}", err)))?;
@@ -422,7 +434,8 @@ impl HALClient {
           .basic_auth(username, password.clone()),
         HttpAuth::Token(token) => self.client
           .request(method, url.clone())
-          .bearer_auth(token)
+          .bearer_auth(token),
+        _ => self.client.request(method, url.clone())
       },
       None => self.client.request(method, url.clone())
     }
@@ -522,7 +535,7 @@ impl Default for HALClient {
       client: reqwest::ClientBuilder::new()
         .build()
         .unwrap(),
-      url: s!(""),
+      url: "".to_string(),
       path_info: None,
       auth: None,
       retries: 3
@@ -551,6 +564,9 @@ pub async fn fetch_pacts_from_broker(
   provider_name: &str,
   auth: Option<HttpAuth>
 ) -> anyhow::Result<Vec<anyhow::Result<(Box<dyn Pact + Send>, Option<PactVerificationContext>, Vec<Link>)>>> {
+  trace!("fetch_pacts_from_broker(broker_url='{}', provider_name='{}', auth={})", broker_url,
+    provider_name, auth.clone().unwrap_or_default());
+
     let mut hal_client = HALClient::with_url(broker_url, auth);
     let template_values = hashmap!{ "provider".to_string() => provider_name.to_string() };
 
@@ -600,7 +616,8 @@ pub async fn fetch_pacts_from_broker(
                   MessagePact::from_json(&href, &pact_json)
                     .map(|pact| (pact.boxed(), None, links))
                 } else {
-                  Ok((RequestResponsePact::from_json(&href, &pact_json).boxed(), None, links))
+                  RequestResponsePact::from_json(&href, &pact_json)
+                    .map(|pact| (pact.boxed(), None, links))
                 },
                 _ => Err(anyhow!("Link '{}' does not point to a valid pact file", href))
               }
@@ -625,8 +642,13 @@ pub async fn fetch_pacts_dynamically_from_broker(
   consumer_version_selectors: Vec<ConsumerVersionSelector>,
   auth: Option<HttpAuth>
 ) -> Result<Vec<Result<(Box<dyn Pact + Send>, Option<PactVerificationContext>, Vec<Link>), PactBrokerError>>, PactBrokerError> {
+  trace!("fetch_pacts_dynamically_from_broker(broker_url='{}', provider_name='{}', pending={}, \
+    include_wip_pacts_since={:?}, provider_tags: {:?}, consumer_version_selectors: {:?}, auth={})",
+    broker_url, provider_name, pending, include_wip_pacts_since, provider_tags,
+    consumer_version_selectors, auth.clone().unwrap_or_default());
+
     let mut hal_client = HALClient::with_url(broker_url, auth);
-    let template_values = hashmap!{ s!("provider") => provider_name.clone() };
+    let template_values = hashmap!{ "provider".to_string() => provider_name.clone() };
 
     hal_client = hal_client.navigate("pb:provider-pacts-for-verification", &template_values)
     .await
@@ -733,7 +755,10 @@ pub async fn fetch_pacts_dynamically_from_broker(
                   Err(err) => Err(PactBrokerError::ContentError(format!("{}", err)))
                 }
               } else {
-                Ok((RequestResponsePact::from_json(&href, &pact_json).boxed(), Some(context), links))
+                match RequestResponsePact::from_json(&href, &pact_json) {
+                  Ok(pact) => Ok((pact.boxed(), Some(context), links)),
+                  Err(err) => Err(PactBrokerError::ContentError(format!("{}", err)))
+                }
               },
               _ => Err(PactBrokerError::ContentError(format!("Link '{}' does not point to a valid pact file", href)))
             }
@@ -928,16 +953,29 @@ async fn publish_provider_tags(
 
 #[skip_serializing_none]
 #[derive(Serialize, Deserialize, Debug, Clone)]
+#[serde(rename_all = "camelCase")]
 /// Structure to represent a HAL link
 pub struct ConsumerVersionSelector {
   /// Application name to filter the results on
   pub consumer: Option<String>,
   /// Tag
-  pub tag: String,
+  pub tag: Option<String>,
   /// Fallback tag if Tag doesn't exist
   pub fallback_tag: Option<String>,
   /// Only select the latest (if false, this selects all pacts for a tag)
   pub latest: Option<bool>,
+  /// Applications that have been deployed or released
+  pub deployed_or_released: Option<bool>,
+  /// Applications that have been deployed
+  pub deployed: Option<bool>,
+  /// Applications that have been released
+  pub released: Option<bool>,
+  /// Applications in a given environment
+  pub environment: Option<String>,
+  /// Applications with the default branch set in the broker
+  pub main_branch: Option<bool>,
+  /// Applications with the given branch
+  pub branch: Option<String>,
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
@@ -1009,8 +1047,8 @@ mod tests {
   use pact_consumer::*;
   use pact_consumer::prelude::*;
   use pact_matching::Mismatch::MethodMismatch;
-  use pact_matching::models::RequestResponseInteraction;
   use pact_models::{Consumer, PactSpecification, Provider};
+  use pact_models::sync_interaction::RequestResponseInteraction;
 
   use super::*;
   use super::{content_type, json_content_type};
@@ -1063,7 +1101,7 @@ mod tests {
                 .unwrap()
         );
 
-        expect!(content_type(&response)).to(be_equal_to(s!("application/hal+json; charset=utf-8")));
+        expect!(content_type(&response)).to(be_equal_to("application/hal+json; charset=utf-8".to_string()));
     }
 
     #[test]
@@ -1180,15 +1218,15 @@ mod tests {
   #[test]
   fn parse_link_url_replaces_all_tokens_in_href() {
     let client = HALClient::default();
-    let values = hashmap!{ s!("valA") => s!("A"), s!("valB") => s!("B") };
+    let values = hashmap!{ "valA".to_string() => "A".to_string(), "valB".to_string() => "B".to_string() };
 
-    let link = Link { name: s!("link"), href: Some(s!("http://localhost")), templated: false, title: None };
+    let link = Link { name: "link".to_string(), href: Some("http://localhost".to_string()), templated: false, title: None };
     expect!(client.clone().parse_link_url(&link, &values)).to(be_ok().value("http://localhost"));
 
-    let link = Link { name: s!("link"), href: Some(s!("http://{valA}/{valB}")), templated: false, title: None };
+    let link = Link { name: "link".to_string(), href: Some("http://{valA}/{valB}".to_string()), templated: false, title: None };
     expect!(client.clone().parse_link_url(&link, &values)).to(be_ok().value("http://A/B"));
 
-    let link = Link { name: s!("link"), href: Some(s!("http://{valA}/{valC}")), templated: false, title: None };
+    let link = Link { name: "link".to_string(), href: Some("http://{valA}/{valC}".to_string()), templated: false, title: None };
     expect!(client.clone().parse_link_url(&link, &values)).to(be_ok().value("http://A/{valC}"));
   }
 
@@ -1196,7 +1234,7 @@ mod tests {
     async fn fetch_link_returns_an_error_if_a_previous_resource_has_not_been_fetched() {
         let client = HALClient::with_url("http://localhost", None);
         let result = client.fetch_link("anything_will_do", &hashmap!{}).await;
-        expect!(result).to(be_err().value(s!("No previous resource has been fetched from the pact broker. URL: 'http://localhost', LINK: 'anything_will_do'")));
+        expect!(result).to(be_err().value("No previous resource has been fetched from the pact broker. URL: 'http://localhost', LINK: 'anything_will_do'".to_string()));
     }
 
     #[tokio::test]
@@ -1283,7 +1321,7 @@ mod tests {
         expect!(result.clone()).to(be_ok());
         client.path_info = result.ok();
         let result = client.clone().fetch_link("next", &hashmap!{}).await;
-        expect!(result).to(be_ok().value(serde_json::Value::String(s!("Yay! You found your way here"))));
+        expect!(result).to(be_ok().value(serde_json::Value::String("Yay! You found your way here".to_string())));
     }
 
     #[tokio::test]
@@ -1309,7 +1347,7 @@ mod tests {
         expect!(result.clone()).to(be_ok());
         client.path_info = result.ok();
         let result = client.clone().fetch_link("next", &hashmap!{}).await;
-        expect!(result).to(be_ok().value(serde_json::Value::String(s!("Yay! You found your way here"))));
+        expect!(result).to(be_ok().value(serde_json::Value::String("Yay! You found your way here".to_string())));
     }
 
     #[tokio::test]
@@ -1335,8 +1373,8 @@ mod tests {
         let result = client.clone().fetch("/").await;
         expect!(result.clone()).to(be_ok());
         client.path_info = result.ok();
-        let result = client.clone().fetch_link("document", &hashmap!{ s!("id") => s!("abc") }).await;
-        expect!(result).to(be_ok().value(serde_json::Value::String(s!("Yay! You found your way here"))));
+        let result = client.clone().fetch_link("document", &hashmap!{ "id".to_string() => "abc".to_string() }).await;
+        expect!(result).to(be_ok().value(serde_json::Value::String("Yay! You found your way here".to_string())));
     }
 
     #[tokio::test]
@@ -1385,13 +1423,13 @@ mod tests {
     #[tokio::test]
     async fn fetch_pacts_from_broker_returns_a_list_of_pacts() {
       try_init().unwrap_or(());
-        let pact = RequestResponsePact { consumer: Consumer { name: s!("Consumer") },
-            provider: Provider { name: s!("happy_provider") },
+        let pact = RequestResponsePact { consumer: Consumer { name: "Consumer".to_string() },
+            provider: Provider { name: "happy_provider".to_string() },
             .. RequestResponsePact::default() }
             .to_json(PactSpecification::V3).unwrap().to_string();
-        let pact2 = RequestResponsePact { consumer: Consumer { name: s!("Consumer2") },
-            provider: Provider { name: s!("happy_provider") },
-            interactions: vec![ RequestResponseInteraction { description: s!("a request friends"), .. RequestResponseInteraction::default() } ],
+        let pact2 = RequestResponsePact { consumer: Consumer { name: "Consumer2".to_string() },
+            provider: Provider { name: "happy_provider".to_string() },
+            interactions: vec![ RequestResponseInteraction { description: "a request friends".to_string(), .. RequestResponseInteraction::default() } ],
             .. RequestResponsePact::default() }
             .to_json(PactSpecification::V3).unwrap().to_string();
         let pact_broker = PactBuilder::new("RustPactVerifier", "PactBroker")
@@ -1470,8 +1508,8 @@ mod tests {
     async fn fetch_pacts_for_verification_from_broker_returns_a_list_of_pacts() {
       try_init().unwrap_or(());
 
-      let pact = RequestResponsePact { consumer: Consumer { name: s!("Consumer") },
-        provider: Provider { name: s!("happy_provider") },
+      let pact = RequestResponsePact { consumer: Consumer { name: "Consumer".to_string() },
+        provider: Provider { name: "happy_provider".to_string() },
         .. RequestResponsePact::default() }
         .to_json(PactSpecification::V3).unwrap().to_string();
 
@@ -1573,11 +1611,17 @@ mod tests {
       })
       .start_mock_server();
 
-    let result = fetch_pacts_dynamically_from_broker(pact_broker.url().as_str(), s!("happy_provider"), false, None, vec!("master".to_string()), vec!(ConsumerVersionSelector {
+    let result = fetch_pacts_dynamically_from_broker(pact_broker.url().as_str(), "happy_provider".to_string(), false, None, vec!("master".to_string()), vec!(ConsumerVersionSelector {
       consumer: None,
-      tag: "prod".to_string(),
+      tag: Some("prod".to_string()),
       fallback_tag: None,
-      latest: None
+      latest: None,
+      branch: None,
+      deployed_or_released: None,
+      deployed: None,
+      released: None,
+      main_branch: None,
+      environment: None,
     }), None).await;
 
     match &result {
@@ -1659,11 +1703,17 @@ mod tests {
       })
     .start_mock_server();
 
-    let result = fetch_pacts_dynamically_from_broker(pact_broker.url().as_str(), s!("sad_provider"), false, None, vec!("master".to_string()), vec!(ConsumerVersionSelector {
+    let result = fetch_pacts_dynamically_from_broker(pact_broker.url().as_str(), "sad_provider".to_string(), false, None, vec!("master".to_string()), vec!(ConsumerVersionSelector {
       consumer: None,
-      tag: "prod".to_string(),
+      tag: Some("prod".to_string()),
       fallback_tag: None,
-      latest: None
+      latest: None,
+      branch: None,
+      deployed_or_released: None,
+      deployed: None,
+      released: None,
+      main_branch: None,
+      environment: None,
     }), None).await;
 
     match result {
